#!/bin/bash

#shellcheck disable=SC1090,SC1091
source /service-fabric/modules/utils.sh

# Lists all the argocd app details that are in Missing or Degraded state
function get_argocd_apps_status() {
    ARGO_PASSWORD=$(kubectl -n argocd get secrets argocd-admin-password -o jsonpath="{.data.password}" | base64 -d)
    
    section "ArgoCD Deployment Health"
    deployments=$(kubectl -n argocd get deploy --no-headers -o custom-columns=NAME:.metadata.name)
    for deploy in $deployments; do
        check_replicas "$deploy" argocd
    done

    section "ArgoCD Apps Status"
    if ! argocd login --plaintext argocd-server.argocd.svc.cluster.local:80 --grpc-web --username admin --password "$ARGO_PASSWORD" --insecure &>/dev/null;
    then
        add_to_report error "Could not log in to ArgoCD"
        return
    fi

    MISSING_STATUS_APPS=$(argocd app list | grep Missing | awk '{print $1}')
    if [[ -n "${MISSING_STATUS_APPS}" ]];
    then
        add_to_report warn "List of missing apps. Please sync these app from Argocd UI"
        for app in $MISSING_STATUS_APPS; do
            add_to_report execute "argocd app get $app"
        done
    else
        add_to_report info "There are no missing apps in the cluster"
    fi

    DEGRADED_STATUS_APPS=$(argocd app list | grep Degraded | awk '{print $1}')
    if [[ -n "${DEGRADED_STATUS_APPS}" ]];
    then
        add_to_report error "List of degraded apps"
        for app in $DEGRADED_STATUS_APPS; do
            add_to_report execute "argocd app get $app"
        done
    else
        add_to_report info "There are no Degraded apps in the cluster"
    fi
}

get_argocd_apps_status