#!/bin/bash

#shellcheck disable=SC1090,SC1091
source /service-fabric/modules/utils.sh

function dns_resolve() {
    local domain="$1"
    local ips
    ips=$(getent ahosts  "${domain}" | awk '{print $1}' | sort | uniq)
    echo "${ips}"
}

function valid_ip() {
    local ip=$1
    local stat=1
    if [[ $ip =~ ^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}$ ]]; then
        OIFS=$IFS
        IFS="." read -r -a ip_parts <<< "$ip"
        IFS=$OIFS
        [[ ${ip_parts[0]} -le 255 && ${ip_parts[1]} -le 255 \
            && ${ip_parts[2]} -le 255 && ${ip_parts[3]} -le 255 ]]
        stat=$?
    fi
    return $stat
}

function validate_retrieved_ip() {
    local ip_addresses="$1"
    local domain="$2"
    local msg
    if ! valid_ip "$(echo "${ip_addresses}" | xargs -n 1)"
    then
        if [[ -n ${domain} ]]
        then
            msg="Invalid IP(s) Found: ${ip_addresses//$'\n'/,} for ${domain}. Please check DNS configuration."
        else
            msg="Invalid IP(s) Found: ${ip_addresses//$'\n'/,}. Please check DNS configuration."
        fi
        add_to_report error "${msg}"
        return 
    fi
    add_to_report info "Successfully validated $domain"
}

function validate_subdomain() {
    local domain=$1
    ip_addresses=$(dns_resolve "${domain}")
    if [[ -z "${ip_addresses}" ]]
    then
       add_to_report error "No IP Address found for ${domain}. Please check DNS configuration."
    else
        validate_retrieved_ip "${ip_addresses}" "${domain}"
    fi
}

function validate_all_domains() {
    section "Sub-Domains Validation"
    declare -a hosts
    read -r -a hosts <<< "$(kubectl get vs -A -o json | jq '.items[].spec.hosts[]'| tr -d '"' |  uniq | tr '\n' ' ')"
    
    for host in "${hosts[@]}";
    do
        validate_subdomain "$host"
    done
}

validate_all_domains
