#!/bin/bash

#shellcheck disable=SC1090,SC1091
source /service-fabric/modules/utils.sh

# Checks if the port is open for connections
# 1 - Host or IP address
# 2 - Port to be checked
function check_ports_connection() {
    if nc -z -v -w5 "$1" "$2" &>/dev/null;
    then
        add_to_report info "Port $2 is open"
    else
        add_to_report error "Port $2 is not open"
    fi
}

# Checks if istio is installed and the required port connections
function check_istio_connections() {
    ISTIO_EXISTS=$(kubectl -n istio-system get svc istio-ingressgateway)
    if [[ -n "${ISTIO_EXISTS}" ]];
    then
        INGRESS_HOST=$(kubectl -n istio-system get gateway main-gateway -o jsonpath='{.spec.servers[?(@.port.name=="https")].hosts[0]}')
        section "Ingress Connections"
        check_ports_connection "$INGRESS_HOST" 443
    fi
}
check_istio_connections