#! /bin/bash

#shellcheck disable=SC1090,SC1091
source /service-fabric/modules/utils.sh

export EXECUTE_ALL_CHECKS=0
export EXECUTE_INFRA_CHECKS=0
export EXECUTE_FABRIC_CHECKS=0
export EXECUTE_SERVICES_CHECKS=0
export PRINT_ONLY_ERRORS=0

# Parse args utility
function parse_args() {
  while getopts 'hdifsaq' flag "$@"; do
    case "${flag}" in
    d)
      info "Running in debug"
      set -x
      ;;
    h)
      display_usage
      exit 0
      ;;
    i)
      export EXECUTE_INFRA_CHECKS=1
      ;;
    f)
      export EXECUTE_FABRIC_CHECKS=1
      ;;
    s)
      export EXECUTE_SERVICES_CHECKS=1
      ;;
    a)
      export EXECUTE_ALL_CHECKS=1
      ;;
    q)
      export PRINT_ONLY_ERRORS=1
      ;;
    :)
      error "Invalid option: ${OPTARG} requires an argument."
      ;;
    *)
      error "Unexpected option ${flag}"
      ;;
    esac
  done
  shift $((OPTIND - 1))
}

# Takes folder as argument and executes all .sh files from there
function execute_scripts(){
  for file in "$1"/*.sh ; do
    bash "${file}"
  done
}

function main() {
    parse_args "$@"

    add_to_report echo "---DIAGNOSTICS REPORT START---"
    [[ "${EXECUTE_INFRA_CHECKS}" == "1" || "${EXECUTE_ALL_CHECKS}" == "1" ]] && execute_scripts /service-fabric/components/infra
    [[ "${EXECUTE_FABRIC_CHECKS}" == "1" || "${EXECUTE_ALL_CHECKS}" == "1" ]] && execute_scripts /service-fabric/components/fabric
    [[ "${EXECUTE_SERVICES_CHECKS}" == "1" || "${EXECUTE_ALL_CHECKS}" == "1" ]] && execute_scripts /service-fabric/components/services
    
    add_to_report echo "---DIAGNOSTICS REPORT END---"
    cat /tmp/report.logs
}

main "$@"