#!/bin/bash

SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
#shellcheck disable=SC1090,SC1091
source "${SCRIPT_DIR}/../../../modules/utils.sh"

function get_pending_pods_list() {
    PENDING_PODS=$(kubectl get pods -A --field-selector status.phase=Pending 2>/dev/null)

    if [[ -n "${PENDING_PODS}" ]];
    then
        section "Pending Pods"
        add_to_report warn "Following pods are in Pending state"
        add_to_report execute "kubectl get pods -A --field-selector status.phase=Pending"
    fi
}

function get_error_events() {
    ERROR_EVENTS=$(kubectl get events -A --field-selector type=Error 2>/dev/null)

    if [[ -n "${ERROR_EVENTS}" ]];
    then
        section "Error Kubernetes Events"
        add_to_report execute "kubectl get events -A --field-selector type=Error"
    fi
}

function get_critical_events() {
    IMP_EVENTS=$(kubectl get events -A --sort-by=.metadata.creationTimestamp | grep -E 'Failed|BackOff|Unhealthy' 2>/dev/null)

    if [[ -n "${IMP_EVENTS}" ]];
    then
        section "Important Kubernetes Events"
        add_to_report execute "kubectl get events -A --sort-by=.metadata.creationTimestamp | grep -E 'Failed|BackOff|Unhealthy'"
    fi
}

function get_uipath_deployments(){
    section "UiPath Infra Deployments"
    deployments=$(kubectl -n uipath-infra get deploy --no-headers -o custom-columns=NAME:.metadata.name)
    for deploy in $deployments; do
        check_replicas "$deploy" uipath-infra
    done

    section "UiPath Deployments"
    deployments=$(kubectl -n uipath get deploy --no-headers -o custom-columns=NAME:.metadata.name)
    for deploy in $deployments; do
        check_replicas "$deploy" uipath
    done
}

function get_failed_jobs(){
    local namespaces
    local failed_count=0
    local POD_NAME
    local JOB_NAME
    namespaces=(uipath uipath-infra)
    for namespace in "${namespaces[@]}"; do
        jobs=$(kubectl get jobs -n "$namespace" -o name)
        for job in $jobs; do
            failed=$(kubectl -n "$namespace" get "$job" -o jsonpath='{.status.conditions[?(@.type=="Failed")].status}')
            JOB_NAME=$(echo "$job" | cut -d '/' -f2 )
            POD_NAME=$(kubectl -n "$namespace" get pods -l=job-name="$JOB_NAME" -o name | head -1)
            if [[ "$failed" = "True" && -n "${POD_NAME}" ]]; then
                failed_count=$((failed_count+1))
                if [ "$failed_count" -eq "1" ]; then
                    section "Jobs in Failed State"
                fi
                add_to_report error "Job $JOB_NAME is in failed state, please run this command to fetch logs for the same: kubectl -n $namespace logs $POD_NAME"
            fi
        done
    done
}

get_failed_jobs
get_pending_pods_list
get_error_events
get_critical_events
get_uipath_deployments 